[mcclim-cvs] CVS mcclim/Drei
thenriksen
thenriksen at common-lisp.net
Thu Jan 31 11:19:36 UTC 2008
Update of /project/mcclim/cvsroot/mcclim/Drei
In directory clnet:/tmp/cvs-serv18673/Drei
Modified Files:
input-editor.lisp
Log Message:
Only constrain point/mark when we actually have a prompt.
You can now delete the leading command in the Listener!
--- /project/mcclim/cvsroot/mcclim/Drei/input-editor.lisp 2008/01/30 22:11:35 1.31
+++ /project/mcclim/cvsroot/mcclim/Drei/input-editor.lisp 2008/01/31 11:19:35 1.32
@@ -571,10 +571,16 @@
;; we may need to do some stuff first.
(unwind-protect
(accepting-from-user (drei)
- ;; We narrow the buffer to the input position, so the user won't
- ;; be able to erase the original command (when entering command
- ;; arguments) or stuff like argument prompts.
- (drei-core:with-narrowed-buffer (drei (input-position stream) t t)
+ ;; We narrow the buffer to the last object before
+ ;; input-position, so the user will not be able to
+ ;; delete arguments prompts or other things.
+ (drei-core:with-narrowed-buffer (drei
+ (loop for index from (1- (input-position stream)) above 0
+ when (typep (buffer-object (buffer (view drei)) index)
+ 'noise-string)
+ return (1+ index)
+ finally (return 0))
+ t t)
(handler-case (process-gestures-or-command drei)
(unbound-gesture-sequence (c)
(display-message "~A is unbound" (gesture-name (gestures c))))
More information about the Mcclim-cvs
mailing list